<template>
  <div class="page" v-if="data != ''">
    <div class="tips_box" v-if="showTip != ''">
      {{ showTip }}
    </div>
    <div :class="['top_box', showTip != '' ? 'margin_top_box_40' : '']">
      <div class="top_box_text">
        答题进度：{{ count }}/{{ data.groomerExamQuestionsList.length }}
      </div>
      <div class="lineBox">
        <div
          class="line"
          :style="
            'width:' +
            (count * 100) / data.groomerExamQuestionsList.length +
            '%'
          "
        ></div>
      </div>
      <div class="count">
        <van-count-down
          class="top_box_text"
          use-slot
          ref="countDown"
          format="mm:ss"
          :time="data.examDuration * 60 * 1000"
          @change="onTimeChange"
          @finish="onTimeFinish"
        >
        </van-count-down>
      </div>
    </div>
    <div :class="['content', showTip != '' ? 'margin_top_box_40' : '']">
      <div
        class="subject"
        v-for="(item, i) in data.groomerExamQuestionsList"
        :key="i"
      >
        <div class="title">{{ i + 1 }}、{{ item.questionContent }}</div>
        <van-radio-group
          v-if="item.questionType === '1'"
          v-model="result[i].selectOptionId"
          checked-color="#2660ff"
          @change="radioChange(i)"
        >
          <div
            v-for="(itemOptions, i) in item.groomerExamQuestionsOptionsList"
            :key="i"
          >
            <van-radio :name="itemOptions.optionId" class="box">{{
              itemOptions.optionContent
            }}</van-radio>
          </div>
        </van-radio-group>
        <van-checkbox-group
          v-if="item.questionType === '2'"
          v-model="result[i].selectOptionId"
          checked-color="#2660ff"
          @change="radioChange(i)"
        >
          <div
            v-for="(itemOptions, i) in item.groomerExamQuestionsOptionsList"
            :key="i"
          >
            <van-checkbox
              :name="itemOptions.optionId"
              shape="square"
              class="box"
              >{{ itemOptions.optionContent }}</van-checkbox
            >
          </div>
        </van-checkbox-group>
      </div>
    </div>
    <div class="btn_box">
      <div class="btn" @click="handleClick('cancel')">返回</div>
      <div class="btn" @click="handleClick('submit')">完成考试</div>
    </div>
  </div>
</template>

<script>
import {
  postGroomerBeginExam,
  postGroomerCommitWrittenExam,
} from "../../request/api";
import { Dialog, Toast } from "vant";
import moment from "moment";
export default {
  data() {
    return {
      data: "",
      result: [],
      count: 0, //已答题数量
      num: 0, //统计计数使用
      showTip: "", //提示文案
    };
  },
  created() {
    this.initData();
  },
  mounted() {
    window["handleClickCancel"] = () => {
      this.handleClick("cancel");
    };
  },

  methods: {
     //初始化数据
    initData() {
      Toast.loading({
        message: "试题加载中...",
        forbidClick: true,
      });
      let data = {
        id: sessionStorage.getItem("id"),
      };
      postGroomerBeginExam( data ).then((res) => {
        if (res.rc == "0") {
          this.data = res.data;
          document.title = this.data.examPaperName || "美容师资格认证理论考试";
          this.setResult();
        } else {
          Toast(res.msg);
          setTimeout(function () {
            if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
              window.webkit.messageHandlers.H5Finish.postMessage({});
            } else {
              window.js.H5Finish();
            }
          }, 1000);
        }
      });
    },
    // 根据问题列表生成 result 结构
    setResult() {
      let result = [];
      if (!this.data.groomerExamQuestionsList.length) {
        result = [{}];
      } else {
        for (let i = 0; i < this.data.groomerExamQuestionsList.length; i++) {
          if (this.data.groomerExamQuestionsList[i].questionType == "1") {
            result.push({
              questionId: this.data.groomerExamQuestionsList[i].questionId,
              selectOptionId: "",
              selectOptionTime: "",
            });
          } else if (
            this.data.groomerExamQuestionsList[i].questionType == "2"
          ) {
            result.push({
              questionId: this.data.groomerExamQuestionsList[i].questionId,
              selectOptionId: [],
              selectOptionTime: "",
            });
          }
        }
      }
      this.result = result;
    },
    radioChange(i) {
      this.count = 0;
      if (this.data.groomerExamQuestionsList[i].questionType === "1") {
        this.result[i].selectOptionTime = moment().format(
          "YYYY-MM-DD HH:mm:ss"
        );
      } else if (this.data.groomerExamQuestionsList[i].questionType === "2") {
        if (this.result[i].value.length > 0) {
          this.result[i].selectOptionTime = moment().format(
            "YYYY-MM-DD HH:mm:ss"
          );
        } else {
          this.result[i].selectOptionTime = "";
        }
      }
      for (let i = 0; i < this.result.length; i++) {
        if (this.result[i].selectOptionTime) {
          this.count++;
        }
      }
    },
    // 倒计时
    onTimeChange(e) {
      let hours = e.hours;
      let minutes = e.minutes;
      let seconds = e.seconds;
      if (hours == 0 && minutes == 3 && seconds == 0) {
        this.showTip = "距考试结束还有3分钟，请注意考试时间！";
      }
      if (hours == 0 && minutes == 2 && seconds == 0) {
        this.showTip = "距考试结束还有2分钟，请注意考试时间！";
      }
      if (hours == 0 && minutes == 1 && seconds == 0) {
        this.showTip = "距考试结束还有1分钟，请注意考试时间！";
      }
      if (hours == 0 && minutes == 0 && seconds == 5) {
        this.showTip = "考试时间即将结束，稍后会自动提交！";
      }
      if (this.num++ % 5 == 0) {
        let data = {
          examPaperId: this.data.examPaperId, //String类型
          endExamTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
          commitExamType: "2", //1：正常提交 2：异常提交 3:自动提交
          lastSelectedTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
          writtenInfoId: this.data.writtenInfoId, //String类型
          commitWrittenExamDetailRequests: this.result,
        };
        if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
          window.webkit.messageHandlers.syncBeauticianExamData.postMessage({
            id: this.data.writtenInfoId,
            data: JSON.stringify(data),
          });
        } else {
          window.js.syncBeauticianExamData(
            this.data.writtenInfoId,
            JSON.stringify(data)
          );
        }
      }
    },
    // 倒计时结束时触发
    onTimeFinish(e) {
      let This = this;
      setTimeout(function () {
        Toast.loading({
          message: "答题时间结束,提交中...",
          forbidClick: true,
        });
        let data = {
          examPaperId: This.data.examPaperId, //String类型
          endExamTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
          commitExamType: "1", //1：正常提交 2：异常提交 3:自动提交
          lastSelectedTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
          writtenInfoId: This.data.writtenInfoId, //String类型
          commitWrittenExamDetailRequests: This.result,
        };
        postGroomerCommitWrittenExam( data ).then((res) => {
          if (res.rc == "0") {
            if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
              window.webkit.messageHandlers.syncBeauticianExamData.postMessage({
                id: This.data.writtenInfoId,
                data: "",
              });
            } else {
              window.js.syncBeauticianExamData(This.data.writtenInfoId, "");
            }
            This.$router.replace({ name: "ckuBeauticianExamSuccess" });
          } else {
            Toast(res.msg);
          }
        });
      }, 10000);
    },
    handleClick(type) {
      Dialog.confirm({
        confirmButtonColor: "#2660ff",
        title: type == "submit" ? "是否确认提交？" : "是否返回？",
        message:
          type == "submit"
            ? "正在进行提交答案，请确认是否答题完毕。"
            : "是否立即中断当前考试？造成严重后果需自行承担，还请知悉。",
      })
        .then(() => {
          // on confirm
          Toast.loading({
            message: "加载中...",
            forbidClick: true,
          });
          let data = {
            examPaperId: this.data.examPaperId, //String类型
            endExamTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
            commitExamType: "1", //1：正常提交 2：异常提交 3:自动提交
            lastSelectedTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
            writtenInfoId: this.data.writtenInfoId, //String类型
            commitWrittenExamDetailRequests: this.result,
          };
          postGroomerCommitWrittenExam(data).then((res) => {
            if (res.rc == "0") {
              if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                window.webkit.messageHandlers.syncBeauticianExamData.postMessage(
                  {
                    id: this.data.writtenInfoId,
                    data: "",
                  }
                );
              } else {
                window.js.syncBeauticianExamData(this.data.writtenInfoId, "");
              }
              if (type == "submit") {
                this.$router.replace({ name: "ckuBeauticianExamSuccess" });
              } else {
                if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                  window.webkit.messageHandlers.H5Finish.postMessage({});
                } else {
                  window.js.H5Finish();
                }
              }
            } else {
              Dialog.confirm({
                confirmButtonColor: "#2660ff",
                title: "答案提交失败，是否再试一次？",
                confirmButtonText: "再试一次",
              })
                .then(() => {
                  // on confirm
                  Toast.loading({
                    message: "加载中...",
                    forbidClick: true,
                  });
                  let data = {
                    examPaperId: this.data.examPaperId, //String类型
                    endExamTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
                    commitExamType: "1", //1：正常提交 2：异常提交 3:自动提交
                    lastSelectedTime: moment().format("YYYY-MM-DD HH:mm:ss"), //datetime类型
                    writtenInfoId: this.data.writtenInfoId, //String类型
                    commitWrittenExamDetailRequests: this.result,
                  };
                  postGroomerCommitWrittenExam( data ).then((res) => {
                    if (res.rc == "0") {
                      if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                        window.webkit.messageHandlers.syncBeauticianExamData.postMessage(
                          {
                            id: this.data.writtenInfoId,
                            data: "",
                          }
                        );
                      } else {
                        window.js.syncBeauticianExamData(
                          this.data.writtenInfoId,
                          ""
                        );
                      }
                      if (type == "submit") {
                        this.$router.replace({
                          name: "ckuBeauticianExamSuccess",
                        });
                      } else {
                        if (
                          /(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)
                        ) {
                          window.webkit.messageHandlers.H5Finish.postMessage(
                            {}
                          );
                        } else {
                          window.js.H5Finish();
                        }
                      }
                    } else {
                      if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                        window.webkit.messageHandlers.H5Finish.postMessage({});
                      } else {
                        window.js.H5Finish();
                      }
                    }
                  });
                })
                .catch(() => {
                  // on cancel
                  if (/(iPhone|iPad|iPod|iOS)/i.test(navigator.userAgent)) {
                    window.webkit.messageHandlers.H5Finish.postMessage({});
                  } else {
                    window.js.H5Finish();
                  }
                });
            }
          });
        })
        .catch(() => {
          // on cancel
        });
    },
  },
};
</script>


<style scoped>
.page {
  min-height: 100vh;
  background: #ffffff;
}
.tips_box {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  z-index: 100;
  box-sizing: border-box;
  background: #fff7cc;
  line-height: 40px;
  text-align: center;
  font-size: 16px;
  color: #ff3360;
}
.top_box {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  display: flex;
  box-sizing: border-box;
  background: #ccc;
  z-index: 100;
  align-items: center;
}
.margin_top_box_40 {
  margin-top: 40px;
}
.count {
  margin-left: auto;
}
.lineBox {
  height: 0.08rem;
  width: 3.5rem;
  background: #ffffff;
  border-radius: 1rem;
  position: relative;
}
.lineBox .line {
  height: 100%;
  width: 0.1rem;
  border-radius: 1rem;
  background: #2660ff;
}
.content {
  padding: 1rem 0 2rem;
}
.subject {
  padding: 0.1rem 0.16rem;
  font-size: 0.14rem;
  border-bottom: 0.01rem solid #f0f0f0;
}
.van-radio,
.van-checkbox {
  padding-top: 0.1rem;
}
.title {
  text-align: left;
  line-height: 0.5rem;
  padding: 0.1rem;
  margin-bottom: 0.05rem;
  font-size: 0.3rem;
  color: #333333;
  word-break: break-all;
  word-wrap: break-word;
}
.top_box_text {
  line-height: 0.5rem;
  font-size: 0.26rem;
  color: #333333;
  word-break: break-all;
  word-wrap: break-word;
  margin: 0.2rem;
}
.box {
  text-align: left;
  line-height: 0.5rem;
  border-radius: 0.5rem;
  margin-bottom: 0.05rem;
  padding: 0.2rem;
  font-size: 0.24rem;
  color: #333333;
  word-break: break-all;
  word-wrap: break-word;
}
.btn_box {
  position: fixed;
  display: flex;
  bottom: 0;
  left: 0;
  width: 100%;
  justify-content: center;
  background: #ccc;
  box-sizing: border-box;
  padding: 0.4rem;
}
.btn_box .btn {
  line-height: 0.7rem;
  width: 2.6rem;
  text-align: center;
  border-radius: 0.35rem;
  color: #fff;
  background: #2660ff;
  font-size: 0.28rem;
  font-weight: 600;
  margin: 0 0.2rem;
}
</style>
